package net.projectmonkey.spring.acl.hbase.repository;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import org.springframework.security.acls.model.AclCache;
import org.springframework.security.acls.model.MutableAcl;
import org.springframework.security.acls.model.ObjectIdentity;

/*
	Copyright 2012 Andy Moody
	
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	    http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/

public class TestingInMemoryCache implements AclCache {

	private final Map<Serializable, MutableAcl> cache = new HashMap<Serializable, MutableAcl>();
	
	@Override
	public void evictFromCache(final Serializable pk) {
		cache.remove(pk);
	}

	@Override
	public void evictFromCache(final ObjectIdentity objectIdentity) {
		evictFromCache(objectIdentity.getIdentifier());
	}

	@Override
	public MutableAcl getFromCache(final ObjectIdentity objectIdentity) {
		return getFromCache(objectIdentity.getIdentifier());
	}

	@Override
	public MutableAcl getFromCache(final Serializable pk) {
		return cache.get(pk);
	}

	@Override
	public void putInCache(final MutableAcl acl) {
		cache.put(acl.getObjectIdentity().getIdentifier(), acl);
	}

	@Override
	public void clearCache() {
		cache.clear();
	}

}
