package net.projectmonkey.spring.acl.util;

import org.springframework.security.acls.domain.GrantedAuthoritySid;
import org.springframework.security.acls.domain.PrincipalSid;
import org.springframework.security.acls.model.Sid;

/*
	Copyright 2012 Andy Moody
	
	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at
	
	    http://www.apache.org/licenses/LICENSE-2.0
	
	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.
*/

public class SidUtil {
	
	public static String resolveAuthority(final Sid sid) {
		String authority;
		if(sid instanceof PrincipalSid){
			authority = ((PrincipalSid) sid).getPrincipal();
		}else{
			authority = ((GrantedAuthoritySid) sid).getGrantedAuthority();
		}
		return authority;
	}
	
	public static boolean isPrincipal(final Sid sid){
		return sid instanceof PrincipalSid;
	}
	
	public static Sid createSid(final String authority, final boolean principal){
		Sid toReturn = null;
		if(principal){
			toReturn = new PrincipalSid(authority);
		}else{
			toReturn = new GrantedAuthoritySid(authority);
		}
		return toReturn; 
	}

}
